Extremely lightweight Docker alternative for agents and production services.
Nucleus provides isolated execution using Linux cgroups, namespaces, seccomp, Landlock, and optional gVisor integration. It implements a subset of the OCI runtime spec and can be used both as a CLI tool and as a library.
Re-exports
pub use error::NucleusError;pub use error::Result;pub use error::StateTransition;