Module container

Module container 

Structs

Container
Container runtime that orchestrates all isolation mechanisms
ContainerConfig
Container configuration
ContainerLifecycle
Container lifecycle operations (stop, kill, delete)
ContainerState
Container state tracking information
ContainerStateManager
Container state manager
ContainerStateParams
Parameters for creating a new ContainerState.
CreatedContainer
Handle returned by Container::create() representing a container whose child process has been forked and is blocked on the exec FIFO, waiting for start() to release it.
HealthCheck
Health check configuration for long-running services.
ProcessIdentity
Runtime identity for the workload process inside the container.
SecretMount
Secrets configuration for mounting secret files into the container.
VolumeMount
Volume configuration for mounting persistent or ephemeral storage.

Enums

KernelLockdownMode
Required host kernel lockdown mode, when asserted by the runtime.
NetworkModeArg
CLI-level network mode selection.
OciStatus
OCI-compliant container status
ReadinessProbe
Readiness probe configuration.
RuntimeSelection
CLI-level runtime selection.
SeccompMode
Seccomp operating mode.
ServiceMode
Service mode for the container.
TrustLevel
Trust level for a container workload.
VolumeSource
Source backing for a volume mount.

Functions

generate_container_id
Generate a unique 32-hex-char container ID (128-bit) using /dev/urandom.
parse_signal
Parse a signal name or number string into a Signal
validate_container_name
Validate a container name for safe use.
validate_hostname
Validate a hostname according to RFC 1123.