ProcessIdentity

Struct ProcessIdentity 

pub struct ProcessIdentity {
    pub uid: u32,
    pub gid: u32,
    pub additional_gids: Vec<u32>,
}
Runtime identity for the workload process inside the container.

Fields

uid: u32

Primary user ID for the workload process.

gid: u32

Primary group ID for the workload process.

additional_gids: Vec<u32>

Supplementary group IDs for the workload process.

Implementations

Source

impl ProcessIdentity

pub fn root() -> Self

Root identity (the historical default).

pub fn is_root(&self) -> bool

Returns true when the workload keeps the default root identity.