Module isolation

Module isolation 

Structs

ContainerAttach
Attach to a running container by entering its namespaces
IdMapping
UID/GID mapping configuration for user namespaces
NamespaceCommandRunner
Run trusted helper actions inside a container’s namespaces.
NamespaceConfig
Namespace configuration
NamespaceManager
Namespace manager
UserNamespaceConfig
User namespace configuration
UserNamespaceMapper
User namespace mapper

Enums

NamespaceProbe
Minimal probe operations that can be executed after joining container namespaces.
NamespaceState
Namespace lifecycle state machine matching Nucleus_Isolation_NamespaceLifecycle.tla