IdMapping

Struct IdMapping 

pub struct IdMapping {
    pub container_id: u32,
    pub host_id: u32,
    pub count: u32,
}
UID/GID mapping configuration for user namespaces

Maps a range of UIDs/GIDs inside the container to a range outside

Fields

container_id: u32

ID inside the container

host_id: u32

ID outside the container (on the host)

count: u32

Number of IDs to map

Implementations

Source

impl IdMapping

pub fn new(container_id: u32, host_id: u32, count: u32) -> Self

Create a new ID mapping with validation

pub fn validate(&self, allow_host_root: bool) -> Result<()>

Validate the mapping for safety.

Rejects zero count, overflow in ID ranges, and excessively large mappings that could map the entire host UID/GID space.

pub fn rootless() -> Self

Create a mapping for root inside container to current user outside